import 'package:apus_drones_mobile/constants/OrderStatus.dart';
import 'package:apus_drones_mobile/constants/UserType.dart';
import 'package:apus_drones_mobile/models/PartnerOrderModel.dart';
import 'package:apus_drones_mobile/screens/Appbar.dart';
import 'package:apus_drones_mobile/services/OrderService.dart';
import 'package:apus_drones_mobile/services/PartnerService.dart';
import 'package:apus_drones_mobile/widgets/BotNavBar.dart';
import 'package:apus_drones_mobile/widgets/Fee.dart';
import 'package:apus_drones_mobile/screens/PartnerOrdersScreen.dart';
import 'package:apus_drones_mobile/widgets/PartnerOrderDetailsHeader.dart';
import 'package:apus_drones_mobile/widgets/ProductCard.dart';
import 'package:apus_drones_mobile/widgets/StatusButton.dart';
import 'package:flutter/material.dart';

class PartnerOrderDetailsScreen extends StatefulWidget {
  final int id;
  PartnerOrderDetailsScreen({Key? key, required this.id}) : super(key: key);

  @override
  _PartnerOrderDetailsState createState() => _PartnerOrderDetailsState();
}

class _PartnerOrderDetailsState extends State<PartnerOrderDetailsScreen> {
  late PartnerOrderModel order;
  PartnerService partnerService = new PartnerService();
  OrderService orderService = new OrderService();
  bool orderReceived = false;

  _fetchOrder() {
    partnerService.getOrder(widget.id).then((o) => this.setState(() {
          order = o;
          orderReceived = true;
        }));
  }

  @override
  void initState() {
    super.initState();
    orderReceived = false;
    this._fetchOrder();
  }

  @override
  Widget build(BuildContext context) {
    return render();
  }

  Scaffold render() {
    if (orderReceived) {
      return Scaffold(
          appBar: Appbar(title: 'Pedido ${order.id}'),
          bottomNavigationBar: BotNavBar(role: UserType.PARTNER),
          body: Container(
            margin: EdgeInsets.symmetric(horizontal: 12.0),
            child: Column(
              children: [
                Padding(
                  padding: EdgeInsets.all(16),
                  child: Container(
                    child: StatusButton(status: this.order.status),
                  ),
                ),
                PartnerOrderDetailsHeader(order: this.order),
                Container(
                    alignment: Alignment.centerLeft,
                    margin: EdgeInsets.only(left: 12.0),
                    child: Text(
                      'Produtos:',
                      style: TextStyle(fontSize: 20),
                    )),
                Expanded(child: _generateItems()),
                Container(
                  margin: EdgeInsets.only(
                    top: 25.0,
                  ),
                  child: Column(
                    children: _buildFooter(context),
                  ),
                ),
              ],
            ),
          ));
    }
    return Scaffold();
  }

  ListView _generateItems() {
    List<ProductCard> products = this
        .order
        .items
        .map((item) => ProductCard(
              product: item.product,
              quantity: item.quantity,
            ))
        .toList();
    return ListView.builder(
      shrinkWrap: true,
      itemBuilder: (context, index) => Column(
        children: products,
      ),
      itemCount: products.length,
    );
  }

  List<Widget> _buildFooter(BuildContext context) {
    List<Widget> footernWidgets = [
      Fee(
          productsSumPrice: this.order.orderPrice,
          deliveryFee: this.order.deliveryPrice,
          totalPrice: _totalPrice(this.order))
    ];
    if (this.order.status == OrderStatus.ACCEPTED) {
      footernWidgets.add(
          _buildButton(context, "Pronto para entrega", OrderStatus.PICKING_UP));
    } else if (this.order.status == OrderStatus.PICKING_UP) {
      footernWidgets
          .add(_buildButton(context, "Recolhido", OrderStatus.IN_FLIGHT));
    }
    return footernWidgets;
  }

  Widget _buildButton(
      BuildContext context, String buttonMessage, OrderStatus toStatus) {
    return Align(
        alignment: Alignment.bottomCenter,
        child: ElevatedButton(
            onPressed: () {
              _updateOrderStatus(toStatus).then((_) => Navigator.push(
                  context,
                  MaterialPageRoute(
                      builder: (context) => PartnerOrdersScreen())));
            },
            style: ElevatedButton.styleFrom(
                padding:
                    EdgeInsets.only(top: 12, left: 60, right: 60, bottom: 12),
                shape: RoundedRectangleBorder(
                    borderRadius: BorderRadius.all(Radius.circular(4)))),
            child: Text(buttonMessage,
                style: TextStyle(
                  fontSize: 16,
                  color: Colors.white,
                ))));
  }

  Future<PartnerOrderModel?> _updateOrderStatus(OrderStatus toStatus) {
    this.order.status = toStatus;
    return orderService.updateOrder(this.order);
  }
}

double _totalPrice(PartnerOrderModel order) =>
    order.orderPrice + order.deliveryPrice;
