import 'package:apus_drones_mobile/constants/UserType.dart';
import 'package:apus_drones_mobile/screens/Appbar.dart';
import 'package:apus_drones_mobile/widgets/BotNavBar.dart';
import 'package:flutter/material.dart';

class PaymentScreen extends StatelessWidget {
  static final String routeName = 'Payment';

  const PaymentScreen({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: Appbar(title: 'Pagamento'),
      resizeToAvoidBottomInset: false,
      backgroundColor: Colors.grey.shade100,
      body: SafeArea(
        child: SingleChildScrollView(
          child: Padding(
            padding: const EdgeInsets.all(12.0),
            child: Column(
              children: [
                Container(
                    child: Column(
                  children: [
                    this._renderPaymentOption('Pix', 'aprovado na hora',
                        'https://jocumpr.com.br/wp-content/uploads/2021/08/logo-pix-icone-1024.png'),
                    this._renderPaymentOption(
                        'Cartão de Crédito',
                        'aprovado na hora',
                        'https://thumbs.dreamstime.com/b/%C3%ADcone-do-cart%C3%A3o-de-cr%C3%A9dito-123471479.jpg'),
                    this._renderPaymentOption(
                        'Cartão de Débito',
                        'aprovado na hora',
                        'https://encrypted-tbn0.gstatic.com/images?q=tbn:ANd9GcQMd6USCIiv3mWI49F_8VyytYblNAMXTL0y8A&usqp=CAU'),
                    this._renderPaymentOption('Boleto', '3 dias após pagamento',
                        'https://lh3.googleusercontent.com/IgqiYqtowoVwAsoBQ9WEfG8HOBF75kbpyaE2CEdSZZsrSZDMjvzPk0uJb79ERq5_2co'),
                    this._renderPaymentOption('Apple Pay', 'aprovado na hora',
                        'https://upload.wikimedia.org/wikipedia/commons/thumb/b/b0/Apple_Pay_logo.svg/2560px-Apple_Pay_logo.svg.png'),
                  ],
                )),
                Align(
                  alignment: Alignment.bottomCenter,
                  child: Padding(
                    padding: const EdgeInsets.only(bottom: 10),
                    child: ElevatedButton(
                      onPressed: () {
                        checkOutAlertDialog(context);
                      },
                      style: ElevatedButton.styleFrom(
                          padding: EdgeInsets.only(
                              top: 12, left: 60, right: 60, bottom: 12),
                          shape: RoundedRectangleBorder(
                              borderRadius:
                                  BorderRadius.all(Radius.circular(4)))),
                      child: Text(
                        "Finalizar compra",
                        style: TextStyle(
                          fontSize: 16,
                          color: Colors.white,
                        ),
                      ),
                    ),
                  ),
                ),
              ],
            ),
          ),
        ),
      ),
      bottomNavigationBar: BotNavBar(
        role: UserType.CUSTOMER,
      ),
    );
  }

  checkOutAlertDialog(BuildContext context) {
    Widget accompanyOrderButton = ElevatedButton(
      style: ElevatedButton.styleFrom(primary: Colors.red),
      child: Text("Acompanhar Pedido"),
      onPressed: () {
        //Ir para a tela de acompanhar pedido
        Navigator.pop(context);
      },
    );

    AlertDialog alertPopUp = AlertDialog(
      title: Text("Compra Finalizada!"),
      content: Text(
          "Obrigado por escolher a Apus Drones. Logo logo seu pedido chegará até você, mas até lá, o próximo passo é você acompanhar o status do seu pedido."),
      actions: [
        accompanyOrderButton,
      ],
    );
    // show the dialog
    showDialog(
      context: context,
      builder: (BuildContext context) {
        return alertPopUp;
      },
    );
  }

  _renderPaymentOption(String title, String subtitle, String image) {
    return Card(
        elevation: 3,
        margin: EdgeInsets.symmetric(horizontal: 50, vertical: 12),
        child: ListTile(
            contentPadding: EdgeInsets.symmetric(vertical: 8, horizontal: 12),
            title: Text(title),
            subtitle: Text(subtitle),
            leading: Container(
              constraints: BoxConstraints.expand(
                height: 200,
                width: 60,
              ),
              decoration: BoxDecoration(
                  borderRadius: BorderRadius.circular(4),
                  image: new DecorationImage(
                    fit: BoxFit.contain,
                    alignment: FractionalOffset.center,
                    image: new NetworkImage(image),
                  )),
            )));
  }
}
