import 'dart:async';

import 'package:apus_drones_mobile/constants/UserType.dart';
import 'package:apus_drones_mobile/models/PartnerModel.dart';
import 'package:apus_drones_mobile/models/PartnerOrderModel.dart';
import 'package:apus_drones_mobile/providers/ProductsToDeliverStateProvider.dart';
import 'package:apus_drones_mobile/widgets/CustomerOrderModal.dart';
import 'package:apus_drones_mobile/widgets/Searchbar.dart';
import 'package:apus_drones_mobile/services/PartnerService.dart';
import 'package:apus_drones_mobile/widgets/BotNavBar.dart';
import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';
import 'package:modal_bottom_sheet/modal_bottom_sheet.dart';
import 'package:shared_preferences/shared_preferences.dart';

import '../Appbar.dart';
import 'ListOfProducts.dart';

class ListOfPartners extends StatefulWidget {
  static final routeName = '/customers/home';
  const ListOfPartners({Key? key}) : super(key: key);

  @override
  _ListOfPartnersState createState() => _ListOfPartnersState();
}

class _ListOfPartnersState extends State<ListOfPartners> {
  int customerId = 3;

  List<PartnerModel> partners = [];
  bool ready = false;

  PartnerService service = new PartnerService();

  List<PartnerOrderModel> orderList = [];

  final productsToDeliverProvider = new ProductsToDeliverStateProvider();

  bool modalOpen = false;

  bool show = false;

  _fetch() {
    service.getAllPartners().then((r) => this.setState(() {
          partners = r;
        }));
  }

  _ListOfPartnersState() {
    _fetch();
    startTimer();
  }

  void startTimer() {
    tick(callNewOrders, 5, 1);
  }

  void tick(Function func, int startTime, int tickId) {
    int time = startTime;
    const oneSec = const Duration(seconds: 1);
    Timer.periodic(oneSec, (Timer timer) {
      if (!mounted) {
        timer.cancel();
        return;
      }

      if (ModalRoute.of(context)!.isCurrent) {
        this.setState(() {});
        if (time <= 0) {
          time = startTime;
          func();
        }
        time--;
        print('Tick ID ${tickId} tempo: ${time}');
      }
    });
  }

  void callNewOrders() async {
    String filter = 'PICKING_UP';
    final orders = await service.getAllOrders(filter);

    final _orderList = orderList;
    for (int i = 0; i < orders.length; i++) {
      if (await verify(orders[i].id)) {
        orderList.insert(0, orders[i]);
      }
    }

    this.setState(() {
      orderList = _orderList;
    });

    modal();
  }

  Future<bool> verify(int id) async {
    final alreadyShowed = await productsToDeliverProvider.getProducts();
    if (alreadyShowed.contains(id)) {
      return false;
    }
    await productsToDeliverProvider.addProduct(id);

    return true;
  }

  void modal() {
    if (orderList.isEmpty) {
      return;
    }
    if (modalOpen) {
      return;
    }
    modalOpen = true;
    show = true;
  }

  void showModal(BuildContext context) {
    if (show) {
      show = false;
      PartnerOrderModel order = orderList[0];
      SchedulerBinding.instance!.addPostFrameCallback((_) {
        showMaterialModalBottomSheet(
          context: context,
          builder: (context) =>
              CustomerOrderModal(order, changeModalOpenToFalse),
        );
      });
    }
  }

  void changeModalOpenToFalse() {
    orderList.removeAt(0);
    modalOpen = false;
  }

  @override
  Widget build(BuildContext context) {
    showModal(context);
    return Scaffold(
      appBar: Appbar(
        title: "Lista de Parceiros",
      ),
      backgroundColor: Colors.white,
      body: Column(
        children: [
          Searchbar(),
          Expanded(
              child: SingleChildScrollView(
            child: getColumnsImageWidgets(),
          ))
        ],
      ),
      bottomNavigationBar: BotNavBar(role: UserType.CUSTOMER),
    );
  }

  Column getColumnsImageWidgets() {
    List<Widget> list = [];

    list.add(Text(
      'Parceiros',
      style: TextStyle(fontSize: 20, fontWeight: FontWeight.bold),
    ));
    for (var i = 0; i < partners.length; i += 2) {
      list.add(
        Padding(
          padding: EdgeInsets.fromLTRB(2, 30, 2, 0.0),
          child: Row(
            mainAxisAlignment: MainAxisAlignment.spaceEvenly,
            children: [getRowChildren(i), getRowChildren(i + 1)],
          ),
        ),
      );
    }

    return new Column(children: list);
  }

  Row getRowChildren(int i) {
    List<Widget> list = [];
    if (i >= partners.length) {
      return Row(
          mainAxisAlignment: MainAxisAlignment.spaceEvenly, children: list);
    }
    list.add(Card(
        elevation: 4,
        child: InkWell(
            onTap: () {
              PartnerModel p = partners[i];
              Navigator.push(context,
                  MaterialPageRoute(builder: (context) => ListOfProducts(p)));
            },
            child: Container(
                decoration: BoxDecoration(
                    borderRadius: BorderRadius.all(Radius.circular(4)),
                    color: Colors.white),
                child: Column(
                  children: [
                    Padding(
                      padding: EdgeInsets.all(10),
                      child: Text(
                        partners[i].name,
                        style: TextStyle(
                            fontWeight: FontWeight.bold, fontSize: 16),
                      ),
                    ),
                    Padding(
                      padding: EdgeInsets.all(20),
                      child: Container(
                        width: 140.0,
                        height: 140.0,
                        decoration: BoxDecoration(
                            shape: BoxShape.circle,
                            border: Border.all(color: Colors.black26),
                            image: DecorationImage(
                                fit: BoxFit.fill,
                                image: NetworkImage(partners[i].avatarUrl))),
                      ),
                    )
                  ],
                )))));
    return new Row(
        mainAxisAlignment: MainAxisAlignment.spaceEvenly, children: list);
  }
}


/*
 onPressed: () {
            Navigator.push(context,
                MaterialPageRoute(builder: (context) => ListOfProducts()));
          },

          */