import 'dart:async';
import 'dart:convert';
import 'package:apus_drones_mobile/assets/config.dart';
import 'package:apus_drones_mobile/models/CreatePartner.dart';
import 'package:apus_drones_mobile/models/PartnerModel.dart';
import 'package:apus_drones_mobile/models/PartnerOrderModel.dart';
import 'package:apus_drones_mobile/models/ProductModel.dart';
import 'package:apus_drones_mobile/providers/AuthProvider.dart';
import 'package:apus_drones_mobile/utils/httpHeaders.dart';
import 'package:http/http.dart' as http;

class PartnerService {
  Future<List<PartnerOrderModel>> getOrders() async {
    http.Response response = await http.get(
      Uri.parse('${Config.apiURL}/orders/by-user'),
      headers: await getHttpHeaders(),
    );
    List<dynamic> rsBody = json.decode(response.body);
    List<PartnerOrderModel> orders =
        rsBody.map((order) => PartnerOrderModel.fromJson(order)).toList();

    return orders;
  }

  Future<PartnerOrderModel> getOrder(int id) async {
    http.Response response = await http.get(
      Uri.parse('${Config.apiURL}/orders/$id'),
      headers: await getHttpHeaders(),
    );
    var rsBody = json.decode(response.body);
    PartnerOrderModel order = PartnerOrderModel.fromJson(rsBody);
    return order;
  }

  Future<List<PartnerOrderModel>> getAllOrders(String filtro) async {
    if (filtro != '') {
      filtro = "?status=" + filtro;
    }
    http.Response response = await http.get(
      Uri.parse('${Config.apiURL}/partners/orders$filtro'),
      headers: await getHttpHeaders(),
    );
    List<dynamic> rsBody = json.decode(response.body);
    List<PartnerOrderModel> orders =
        rsBody.map((order) => PartnerOrderModel.fromJson(order)).toList();

    return orders;
  }

  Future<List<ProductModel>> getProducts() async {
    http.Response response = await http.get(
      Uri.parse('${Config.apiURL}/partners/products'),
      headers: await getHttpHeaders(),
    );
    List<dynamic> rsBody = json.decode(response.body);
    List<ProductModel> products =
        rsBody.map((product) => ProductModel.fromJson(product)).toList();

    return products;
  }

  Future<List<PartnerModel>> getAllPartners() async {
    http.Response response = await http.get(
      Uri.parse('${Config.apiURL}/partners'),
      headers: await getHttpHeaders(),
    );
    List<dynamic> rsBody = json.decode(response.body);
    List<PartnerModel> partners =
        rsBody.map((product) => PartnerModel.fromJson(product)).toList();

    return partners;
  }

  Future<PartnerModel> getProfile() async {
    http.Response response = await http.get(
      Uri.parse('${Config.apiURL}/user/profile'),
      headers: await getHttpHeaders(),
    );
    var rsBody = json.decode(response.body);
    PartnerModel partner = PartnerModel.fromJson(rsBody);
    return partner;
  }

  Future<void> postPartner(CreatePartner partner) async {
    print(json.encode(partner.toJson()));
    try {
      http.Response response = await http.post(
          Uri.parse('${Config.apiURL}/partners'),
          headers: await getHttpHeaders(),
          body: json.encode(partner.toJson()));

      print(response);
    } catch (error) {
      print(error);
    }
  }
}
