import 'package:apus_drones_mobile/models/CustomerModel.dart';
import 'package:apus_drones_mobile/models/OrderItemModel.dart';
import 'package:apus_drones_mobile/models/PartialOrder.dart';
import 'package:apus_drones_mobile/models/PartnerModel.dart';
import 'package:apus_drones_mobile/models/ProductModel.dart';
import 'package:apus_drones_mobile/screens/CartScreen.dart';
import 'package:apus_drones_mobile/services/OrderService.dart';
import 'package:apus_drones_mobile/widgets/WeightAlert.dart';
import 'package:flutter/material.dart';

class AddToCart extends StatelessWidget {
  int? quantity;
  final OrderService service = OrderService();
  final ProductModel product;
  AddToCart({Key? key, required this.product, this.quantity}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return ElevatedButton(
      onPressed: () {
        this._addToCart(context);
      },
      child: Row(
        children: [
          Text(
            "ADICIONAR ",
          ),
          Icon(
            Icons.shopping_cart,
            size: 15,
          ),
        ],
      ),
    );
  }

  _addToCart(BuildContext context) async {
    PartnerModel? partner = product.partner;
    if (partner == null) {
      print('Sem parceiro definido');
      return;
    }

    PartialOrder order = PartialOrder(
        status: 'IN_CART',
        customer: PartialCustomer(1),
        partner: partner,
        items: [
          OrderItemModel(
              id: 0,
              quantity: this.quantity != null ? this.quantity! : 1,
              price: product.price,
              product: product)
        ]);
    try {
      var response = await service.addToCart(order);
      Navigator.of(context).pushNamed(CartScreen.routeName);
    } catch (e) {
      WeightAlert.show(context);
    }
  }
}
